---
title: <span class="badge builder"></span> HeatmapTooltip
---
# <span class="badge builder"></span> HeatmapTooltip

## Constructor

```python
HeatmapTooltip()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> heatmap.HeatmapTooltip
```

### <span class="badge object-method"></span> show

Controls if the tooltip is shown

```python
def show(show: bool) -> typing.Self
```

### <span class="badge object-method"></span> show_color_scale

Controls if the tooltip shows a color scale in header

```python
def show_color_scale(show_color_scale: bool) -> typing.Self
```

### <span class="badge object-method"></span> y_histogram

Controls if the tooltip shows a histogram of the y-axis values

```python
def y_histogram(y_histogram: bool) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [HeatmapTooltip](./object-HeatmapTooltip.md)
